%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Analytical solution of the plate buckling equation%
%                       Andreas Landa                     %
%                      Trondheim, 2013                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%Parameters are defined

a = 10;                                     % Length [in]
b = 10;                                     % Width [in]
h = 0.05;                                   % Thickness [in]
                                            

m = 1;                                      % Mass [lb]
beta = a/b;                                 % Aspect ratio [-]
g = 386.088582677165;                       % Gravitational acceleration 
                                            % [in/s^2]

Ex = 40E+6;                                 % Elastic modulus [psi]
Ey = 4E+6;                                  % Elastic modulus [psi]
Gxy = 1.5E+6;                               % Shear modulus [psi]
vxy = 0.25;                                 % Poissons ratio [-]
vyx = 0.025;                                % Poissons ratio [-]
ny = 0.0585;                                % Specific weight[lb/in^3]

%Dx = 419.3;                                 % Flexural rigidity [psi]
%Dy = 41.93;                                 % Flexural rigidity [psi]
%D1 = 10.48;                                 % Flexural rigidity [psi]
%Dxy = 15.62;                                % Flexural rigidity [psi]

Dx = (Ex*h^3)/(12*(1-vxy*vyx));             % Flexural rigidity [Pa*m^3]
Dy = (Ey*h^3)/(12*(1-vxy*vyx));             % Flexural rigidity [Pa*m^3]
D1 = (Ex*vyx*h^3)/(12*(1-vxy*vyx));         % Flexural rigidity [Pa*m^3]
Dxy = (Gxy*h^3)/12;                         % Flexural rigidity [Pa*m^3

R12 = 0.09953;                              
R22 = 0.1;                                  
p1 = 3311;                                  % [psi]
pcr = 1075;                                 % Yield stress[psi]

c = 537500;                                 % Axial stress wave velocity [in/s] 
ksi_0 = 0.1;                                % Initial imperfection vs. thickness


S = ((p1^3)*g*pi^2)/((c^2)*(a^2)*ny);       % Dynamic similarity number [-]
 
%Defining constants used in system of equations

A = (m.^4+2*R12*m.^2*beta.^2+R22*beta.^4)/4;
B = ((1-vxy*vyx)*(m.^4+R22*beta.^4))/8;


dx = 0.001;
X = 0:dx:2;
Y = zeros(length(X));
G = Y;
Y(1) = 0;                                   % y(0)
G(1) = 0;                                   % y'(0)
tic
for i = 2:length(X)                         % RK1 (euler)
    Y(i) = Y(i-1) + dx*G(i-1);
    G(i) = G(i-1) + dx*(-S*((A*(Y(i-1)-ksi_0))+(B*(Y(i-1)^2-ksi_0^2))*Y(i-1)-m^2*X(i-1)*Y(i-1)));
end
tid = toc;
steprate = i/tid;
disp(['    y(x = ' num2str(2) ') = ' num2str(Y(i))]);
disp(['dy/dx(x = ' num2str(2) ') = ' num2str(G(i))]);
plot(X,Y,'r')
hold on
%plot(X,G,'k')

