%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Analytical solution of the plate buckling equation%
%                       Andreas Landa                     %
%                      Trondheim, 2013                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%Parameters are defined

a = 0.254;                                 % Length [m]
b = 0.254;                                 % Width [m]
h = 0.00127;                               % Thickness [m]
                                            

m = 1;                                     % Mass [kg]
beta = a/b;                                % Aspect ratio [-]
g = 9.81;                                  % Gravitational acceleration  
                                           % [m/s^2]

Ex = 2.76E+11;                             % Elastic modulus [Pa]
Ey = 2.76E+10;                             % Elastic modulus [Pa]
Gxy = 1.03E+10;                            % Shear modulus [Pa]
vxy = 0.25;                                % Poissons ratio [-]
vyx = 0.025;                               % Poissons ratio [-]
ny = 15885.333;                               % Specific weight[kg/m^3]

Dx = 2.89E+6;                              % Flexural rigidity [Pa]
Dy = 2.89E+5;                              % Flexural rigidity [Pa]
D1 = 72257.06;                             % Flexural rigidity [Pa]
Dxy = 107696.11;                           % Flexural rigidity [Pa]



R12 = 0.09953;                              
R22 = 0.1;                                  
p1 = 2.28E+7;                              % [Pa]
pcr = 7411864;                             % Yield stress[Pa]

c = 3705932043;                            % Axial stress wave velocity [m/s] 
ksi_0 = 0.01;                               % Initial imperfection vs. thickness


S = ((p1^3)*g*pi^2)/((c^2)*(a^2)*ny);       % Dynamic similarity number [-]
 
%Defining constants used in system of equations

A = (m.^4+2*R12*m.^2*beta.^2+R22*beta.^4)/4;
B = ((1-vxy*vyx)*(m.^4+R22*beta.^4))/8;


dx = 0.001;
X = 0:dx:2;
Y = zeros(length(X));
G = Y;
Y(1) = 0;                                   % y(0)
G(1) = 0;                                   % y'(0)
tic
for i = 2:length(X)                         % RK1 (euler)
    Y(i) = Y(i-1) + dx*G(i-1);
    G(i) = G(i-1) + dx*(-S*((A*(Y(i-1)-ksi_0))+(B*(Y(i-1)^2-ksi_0^2))*Y(i-1)-m^2*X(i-1)*Y(i-1)));
end
tid = toc;
steprate = i/tid;
disp(['    y(x = ' num2str(2) ') = ' num2str(Y(i))]);
disp(['dy/dx(x = ' num2str(2) ') = ' num2str(G(i))]);
plot(X,Y,'r')
