%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%       Analytical solution of the plate buckling equation%
%                       Andreas Landa                     %
%                      Trondheim, 2013                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%Parameters are defined%

a = 1;                                     % Length [m]
b = 1;                                     % Width [m]
h = 0.01;                                  % Thickness [m]
v = 0.01;                                  % Veloctiy of impacting load
ro = 7850;
                                            
m = 1;                                     % Number of halfwaves in 
                                           % imperfection function
beta = a/b;                                % Aspect ratio [-]
g = 9.81;                                  % Gravitational acceleration  
                                           % [m/s^2]

Ex = 2.1E+11;                              % Elastic modulus [Pa]
Ey = 2.1E+11;                              % Elastic modulus [Pa]
Gxy = 8.08E+10;                            % Shear modulus [Pa]
vxy = 0.3;                                 % Poissons ratio [-]
vyx = 0.3;                                 % Poissons ratio [-]
ny = ro*g;                                 % Specific weight[kg/m^3]

Dx = (Ex*h^3)/(12*(1-vxy*vyx));            % Flexural rigidity [Pa*m^3]
Dy = (Ey*h^3)/(12*(1-vxy*vyx));            % Flexural rigidity [Pa*m^3]
D1 = (Ex*vyx*h^3)/(12*(1-vxy*vyx));        % Flexural rigidity [Pa*m^3]
Dxy = (Gxy*h^3)/12;                        % Flexural rigidity [Pa*m^3

R12 = 1;                              
R22 = 1;                                  
p1 = (4*Dx*pi^2)/(a^2*h);                  % [Pa]
pcr = 240E+16;                             % Yield stress[Pa]

c = Ex*v/a;                                % Axial stress wave velocity 
                                           % [N/m^2*s] 
ksi_0 = 0.1;                               % Initial imperfection 
                                           % vs. thickness


S = ((p1^3)*g*pi^2)/((c^2)*(a^2)*ny);      % Dynamic similarity number [-]
 
%Defining constants used in system of equations%

A = (m.^4+2*R12*m.^2*beta.^2+R22*beta.^4)/4;
B = ((1-vxy*vyx)*(m.^4+R22*beta.^4))/8;


dx = 0.001;
X = 0:dx:2;
Y = zeros(length(X));
G = Y;
Y(1) = 0;                                   % y(0)
G(1) = 0;                                   % y'(0)
tic
for i = 2:length(X)                         % RK1 (euler)
    Y(i) = Y(i-1) + dx*G(i-1);
    G(i) = G(i-1) + dx*(-S*((A*(Y(i-1)-ksi_0))+(B*(Y(i-1)^2-ksi_0^2))*Y(i-1)-m^2*X(i-1)*Y(i-1)));
end
tid = toc;
steprate = i/tid;
disp(['    y(x = ' num2str(2) ') = ' num2str(Y(i))]);
disp(['dy/dx(x = ' num2str(2) ') = ' num2str(G(i))]);
plot(X,Y,'r')
hold on